@@ -51,17 +51,14 @@
 #ifndef G_OS_WIN32
 #include <libepc/consumer.h>
 #include <libsoup/soup-status.h>
-#include <avahi-ui/avahi-ui.h>
 #endif // !G_OS_WIN32
 
-#include <gtk/gtkstock.h> /* For use with the avahi-ui dialog. */
+#include <gtk/gtk.h>
 
 #ifndef G_OS_WIN32
 # include <netdb.h> //For gethostbyname().
 #endif
 
-#include <gtk/gtkuimanager.h>
-
 #include <glibmm/i18n.h>
 
 namespace Glom
@@ -92,7 +89,7 @@ Application::Application(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builde
 #endif // !GLOM_ENABLE_CLIENT_ONLY
   m_show_sql_debug(false)
 {
-  set_icon_name("glom");
+  Gtk::Window::set_default_icon_name("glom");
 
   //Load widgets from glade file:
   builder->get_widget("bakery_vbox", m_pBoxTop);
