@@ -101,6 +101,9 @@ private:
 namespace Glom
 {
 
+const char* Dialog_ExistingOrNew::glade_id("dialog_existing_or_new");
+const bool Dialog_ExistingOrNew::glade_developer(false);
+
 Dialog_ExistingOrNew::Dialog_ExistingOrNew(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder)
 : Gtk::Dialog(cobject)
 {
@@ -161,12 +164,15 @@ Dialog_ExistingOrNew::Dialog_ExistingOrNew(BaseObjectType* cobject, const Glib::
   g_free(dir);
 
   if(!Glib::file_test(path, Glib::FILE_TEST_EXISTS))
-    path = GLOM_DOCDIR G_DIR_SEPARATOR_S "examples";
+    path = GLOM_DOCDIR_EXAMPLES;
 #else
-  const char *const path = GLOM_DOCDIR G_DIR_SEPARATOR_S "examples";
+  const char *const path = GLOM_DOCDIR_EXAMPLES;
 #endif //G_OS_WIN32
 
-  list_examples_at_path(path);
+  //Show the installed example files,
+  //falling back to the ones from the local source tree if none are installed:
+  if(!list_examples_at_path(path))
+    list_examples_at_path(GLOM_DOCDIR_EXAMPLES_NOTINSTALLED);
 
 #endif //!GLOM_ENABLE_CLIENT_ONLY
 
@@ -464,24 +470,24 @@ void Dialog_ExistingOrNew::existing_icon_data_func(Gtk::CellRenderer* renderer,
   return;
 #endif
 
-#ifdef GLIBMM_PROPERTIES_ENABKED
+#ifdef GLIBMM_PROPERTIES_ENABLED
   pixbuf_renderer->property_stock_size() = Gtk::ICON_SIZE_BUTTON;
   pixbuf_renderer->property_stock_id() = "";
   pixbuf_renderer->property_pixbuf() = Glib::RefPtr<Gdk::Pixbuf>();
 
   if(iter == m_iter_existing_recent)
-    pixbuf_renderer->property_stock_id() = Gtk::StockID(Gtk::Stock::INDEX); // TODO: More meaningful icon?
+    pixbuf_renderer->property_stock_id() = Gtk::Stock::INDEX.id; // TODO: More meaningful icon?
 #ifndef G_OS_WIN32
   else if(iter == m_iter_existing_network)
-    pixbuf_renderer->property_stock_id() = Gtk::StockID(Gtk::Stock::NETWORK);
+    pixbuf_renderer->property_stock_id() = Gtk::Stock::NETWORK.id;
 #endif
   else if(iter == m_iter_existing_other)
-    pixbuf_renderer->property_stock_id() = Gtk::StockID(Gtk::Stock::OPEN);
+    pixbuf_renderer->property_stock_id() = Gtk::Stock::OPEN.id;
   else if(m_iter_existing_recent_dummy.get() && iter == *m_iter_existing_recent_dummy)
-    pixbuf_renderer->property_stock_id() = Gtk::StockID(Gtk::Stock::DIALOG_ERROR); // TODO: Use Stock::STOP instead?
+    pixbuf_renderer->property_stock_id() = ""; // TODO: Use Stock::STOP instead?
 #ifndef G_OS_WIN32
   else if(m_iter_existing_network_dummy.get() && iter == *m_iter_existing_network_dummy)
-    pixbuf_renderer->property_stock_id() = Gtk::StockID(Gtk::Stock::DIALOG_ERROR); // TODO: Use Stock::STOP instead?
+    pixbuf_renderer->property_stock_id() = ""; // TODO: Use Stock::STOP instead?
 #endif
 
 #else // Properties enabled
@@ -499,10 +505,10 @@ void Dialog_ExistingOrNew::existing_icon_data_func(Gtk::CellRenderer* renderer,
   else if(iter == m_iter_existing_other)
     pixbuf_renderer->set_property("stock-id", Gtk::StockID(Gtk::Stock::OPEN));
   else if(m_iter_existing_recent_dummy.get() && iter == *m_iter_existing_recent_dummy)
-    pixbuf_renderer->set_property("stock-id", Gtk::StockID(Gtk::Stock::DIALOG_ERROR)); // TODO: Use Stock::STOP instead?
+    pixbuf_renderer->set_property("stock-id", std::string()); // TODO: Use Stock::STOP instead?
 #ifndef G_OS_WIN32
   else if(m_iter_existing_network_dummy.get() && iter == *m_iter_existing_network_dummy)
-    pixbuf_renderer->set_property("stock-id", Gtk::StockID(Gtk::Stock::DIALOG_ERROR)); // TODO: Use Stock::STOP instead?
+    pixbuf_renderer->set_property("stock-id", std::string()); // TODO: Use Stock::STOP instead?
 #endif
 
 #endif // Properties enabled
@@ -955,7 +961,7 @@ void Dialog_ExistingOrNew::on_select_clicked()
     #ifdef GLOM_ENABLE_MAEMO
     Hildon::FileChooserDialog dialog(Gtk::FILE_CHOOSER_ACTION_OPEN);
     #else
-    Gtk::FileChooserDialog dialog(*this, "Choose a glom file to open");
+    Gtk::FileChooserDialog dialog(*this, "Open Glom File");
     dialog.add_button(Gtk::Stock::CANCEL, Gtk::RESPONSE_CANCEL);
     dialog.add_button(Gtk::Stock::OPEN, Gtk::RESPONSE_OK);
     dialog.set_default_response(Gtk::RESPONSE_OK);
