@@ -34,10 +34,6 @@
 #include <libglom/connectionpool_backends/postgres_self.h>
 #endif
 
-#ifdef GLOM_ENABLE_SQLITE
-# include <libglom/connectionpool_backends/sqlite.h>
-#endif
-
 #ifndef GLOM_ENABLE_CLIENT_ONLY
 #include <glom/mode_design/users/dialog_groups_list.h>
 #include <glom/mode_design/dialog_database_preferences.h>
@@ -574,7 +570,6 @@ void Frame_Glom::on_menu_userlevel_Developer(const Glib::RefPtr<Gtk::RadioAction
           //TODO: Obviously this could be possible but it would require a network protocol and some work:
           Gtk::MessageDialog dialog(Utils::bold_message(_("Developer mode not available.")), true, Gtk::MESSAGE_WARNING);
           dialog.set_secondary_text(_("Developer mode is not available because the file was opened over the network from a running Glom. Only the original file may be edited."));
-          dialog.set_icon_name("glom");
           dialog.set_transient_for(*get_app_window());
           dialog.run();
         }
@@ -582,7 +577,6 @@ void Frame_Glom::on_menu_userlevel_Developer(const Glib::RefPtr<Gtk::RadioAction
         {
           Gtk::MessageDialog dialog(Utils::bold_message(_("Developer mode not available")), true, Gtk::MESSAGE_WARNING);
           dialog.set_secondary_text(_("Developer mode is not available. Check that you have sufficient database access rights and that the glom file is not read-only."));
-          dialog.set_icon_name("glom");
           dialog.set_transient_for(*get_app_window());
           dialog.run();
         }
@@ -591,7 +585,6 @@ void Frame_Glom::on_menu_userlevel_Developer(const Glib::RefPtr<Gtk::RadioAction
       {
         Gtk::MessageDialog dialog(Utils::bold_message(_("Saving in new document format")), true, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_NONE);
         dialog.set_secondary_text(_("The document was created by an earlier version of the application. Making changes to the document will mean that the document cannot be opened by some earlier versions of the application."));
-        dialog.set_icon_name("glom");
         dialog.set_transient_for(*get_app_window());
         dialog.add_button(Gtk::Stock::CANCEL, Gtk::RESPONSE_CANCEL);
         dialog.add_button(_("Continue"), Gtk::RESPONSE_OK);
@@ -881,7 +874,6 @@ void Frame_Glom::on_menu_file_import()
   else
   {
     Gtk::FileChooserDialog file_chooser(*get_app_window(), _("Open CSV Document"), Gtk::FILE_CHOOSER_ACTION_OPEN);
-    file_chooser.set_icon_name("glom");
     file_chooser.add_button(Gtk::Stock::CANCEL, Gtk::RESPONSE_CANCEL);
     file_chooser.add_button(Gtk::Stock::OPEN, Gtk::RESPONSE_ACCEPT);
     Gtk::FileFilter filter_csv;
@@ -962,7 +954,6 @@ void Frame_Glom::on_menu_file_toggle_share(const Glib::RefPtr<Gtk::ToggleAction>
   if(shared)
   {
     Gtk::MessageDialog dialog(Utils::bold_message(_("Share on the network")), true, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_NONE);
-    dialog.set_icon_name("glom");
     dialog.set_secondary_text(_("This will allow other users on the network to use this database."));
     dialog.set_transient_for(*get_app_window());
     dialog.add_button(Gtk::Stock::CANCEL, Gtk::RESPONSE_CANCEL);
@@ -1063,7 +1054,6 @@ void Frame_Glom::on_menu_file_toggle_share(const Glib::RefPtr<Gtk::ToggleAction>
     //TODO: Warn about connected users if possible.
     Gtk::MessageDialog dialog(Utils::bold_message(_("Stop sharing on the network")), true, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_NONE);
     dialog.set_secondary_text(_("This will prevent other users on the network from using this database."));
-    dialog.set_icon_name("glom");
     dialog.set_transient_for(*get_app_window());
     dialog.add_button(Gtk::Stock::CANCEL, Gtk::RESPONSE_CANCEL);
     dialog.add_button(_("_Stop Sharing"), Gtk::RESPONSE_OK);
@@ -1461,7 +1451,6 @@ void Frame_Glom::on_button_quickfind()
     note.run();
 #else
     Gtk::MessageDialog dialog(Utils::bold_message(_("No find criteria")), true, Gtk::MESSAGE_WARNING );
-    dialog.set_icon_name("glom");
     dialog.set_secondary_text(message);
     dialog.set_transient_for(*get_app_window());
     dialog.run();
@@ -1712,9 +1701,9 @@ void Frame_Glom::do_menu_developer_fields(Gtk::Window& parent, const Glib::ustri
     add_view(m_pDialog_Fields);
   }
 
-  // Some database backends (SQLite) require the table to change no longer
-  // being in use when changing the records, so clear the database usage
-  // here. We reshow everything in on_developer_dialog_hide anyway.
+  // Some database backends (SQLite) require the table to change to no longer
+  // be in use when changing the records, so we stop the database usage
+  // here. We reshow everything in on_developer_dialog_hide() anyway.
   show_no_table();
 
   // Remember the old table name so that we re-show the previous table as
@@ -1746,7 +1735,6 @@ void Frame_Glom::on_menu_developer_relationships_overview()
 
   if(m_dialog_relationships_overview)
   {
-    m_dialog_relationships_overview->set_icon_name("glom");
     m_dialog_relationships_overview->set_transient_for(*(get_app_window()));
     m_dialog_relationships_overview->load_from_document();
 
@@ -1932,61 +1920,6 @@ void Frame_Glom::on_developer_dialog_hide()
 }
 #endif // !GLOM_ENABLE_CLIENT_ONLY
 
-namespace
-{
-  void setup_connection_pool_from_document(Document* document)
-  {
-    ConnectionPool* connection_pool = ConnectionPool::get_instance();
-    switch(document->get_hosting_mode())
-    {
-#ifdef GLOM_ENABLE_POSTGRESQL
-
-#ifndef GLOM_ENABLE_CLIENT_ONLY
-    case Document::HOSTING_MODE_POSTGRES_SELF:
-      {
-        ConnectionPoolBackends::PostgresSelfHosted* backend = new ConnectionPoolBackends::PostgresSelfHosted;
-        backend->set_self_hosting_data_uri(document->get_connection_self_hosted_directory_uri());
-        connection_pool->set_backend(std::auto_ptr<ConnectionPool::Backend>(backend));
-      }
-      break;
-#endif //GLOM_ENABLE_CLIENT_ONLY
-
-    case Document::HOSTING_MODE_POSTGRES_CENTRAL:
-      {
-        ConnectionPoolBackends::PostgresCentralHosted* backend = new ConnectionPoolBackends::PostgresCentralHosted;
-        backend->set_host(document->get_connection_server());
-        backend->set_port(document->get_connection_port());
-        backend->set_try_other_ports(document->get_connection_try_other_ports());
-        connection_pool->set_backend(std::auto_ptr<ConnectionPool::Backend>(backend));
-      }
-      break;
-#endif //GLOM_ENABLE_POSTGRESQL
-
-#ifdef GLOM_ENABLE_SQLITE
-    case Document::HOSTING_MODE_SQLITE:
-      {
-        ConnectionPoolBackends::Sqlite* backend = new ConnectionPoolBackends::Sqlite;
-        backend->set_database_directory_uri(document->get_connection_self_hosted_directory_uri());
-        connection_pool->set_backend(std::auto_ptr<ConnectionPool::Backend>(backend));
-      }
-      break;
-#endif // GLOM_ENABLE_SQLITE
-
-    default:
-      //on_document_load() should have checked for this already, informing the user.
-      std::cerr << "Glom: setup_connection_pool_from_document(): Unhandled hosting mode: " << document->get_hosting_mode() << std::endl;
-      g_assert_not_reached();
-      break;
-    }
-
-    // Might be overwritten later when actually attempting a connection:
-    connection_pool->set_user(document->get_connection_user());
-    connection_pool->set_database(document->get_connection_database());
-
-    connection_pool->set_ready_to_connect();
-  }
-}
-
 #ifndef GLOM_ENABLE_CLIENT_ONLY
 void Frame_Glom::on_connection_initialize_progress()
 {
@@ -2105,7 +2038,7 @@ bool Frame_Glom::connection_request_password_and_choose_new_database_name()
     return false;
 
   ConnectionPool* connection_pool = ConnectionPool::get_instance();
-  setup_connection_pool_from_document(document);
+  connection_pool->setup_from_document(document);
 
   if(!m_pDialogConnection)
   {
@@ -2383,7 +2316,7 @@ bool Frame_Glom::connection_request_password_and_attempt(bool& database_not_foun
 
   //Start a self-hosted server if necessary:
   ConnectionPool* connection_pool = ConnectionPool::get_instance();
-  setup_connection_pool_from_document(document);
+  connection_pool->setup_from_document(document);
   if(!connection_pool->startup( sigc::mem_fun(*this, &Frame_Glom::on_connection_startup_progress) ))
     return false;
 
