@@ -30,6 +30,9 @@
 namespace Glom
 {
 
+const char* Dialog_Layout_Calendar_Related::glade_id("window_data_layout");
+const bool Dialog_Layout_Calendar_Related::glade_developer(true);
+
 Dialog_Layout_Calendar_Related::Dialog_Layout_Calendar_Related(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder)
 : Dialog_Layout_List(cobject, builder),
   m_combo_relationship(0),
@@ -376,7 +379,7 @@ void Dialog_Layout_Calendar_Related::on_button_add_field()
   //std::cout << "debug table used =" << m_portal->get_table_used(m_table_name) << std::endl;
 
   type_list_field_items fields_list = offer_field_list(m_table_name, this);
-  for(type_list_field_items::iterator iter_chosen = fields_list.begin(); iter_chosen != fields_list.end(); iter_chosen++) 
+  for(type_list_field_items::iterator iter_chosen = fields_list.begin(); iter_chosen != fields_list.end(); ++iter_chosen) 
   {
     sharedptr<LayoutItem_Field> field = *iter_chosen;
     if(!field)
